@@ -9,7 +9,7 @@ cols <- c(
 test_that("Chadwick PlayerID Lookup", {
   skip_on_cran()
   
-  x <- playerid_lookup("Garcia", "Karim")
+  x <- playerid_lookup("Ohtani", "Shohei")
   
   expect_equal(colnames(x), cols)
   expect_s3_class(x, "data.frame")
