@@ -14,6 +14,7 @@ cols <- c(
   "weight",
   "active",
   "use_name",
+  "use_last_name",
   "middle_name",
   "boxscore_name",
   "nick_name",
@@ -36,6 +37,7 @@ cols <- c(
   "draft_year",
   "name_matrilineal",
   "name_title",
+  "name_suffix",
   "last_played_date",
   "current_team_id",
   "current_team_name",
